import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, ChangeDetectionStrategy, ViewChild, Input, Output, HostBinding, HostListener, NgModule, InjectionToken } from '@angular/core';
import { map, filter, debounceTime, distinctUntilChanged, switchMap, shareReplay, startWith } from 'rxjs/operators';
import { wktToGeoJSON } from '@terraformer/wkt';
import * as i1 from '@angular/common/http';
import { HttpClient, provideHttpClient } from '@angular/common/http';
import * as i3 from '@angular/forms';
import { FormControl, Validators, ReactiveFormsModule } from '@angular/forms';
import { BehaviorSubject, Subject, tap, merge, combineLatest, firstValueFrom } from 'rxjs';
import * as i2 from '@angular/common';
import { AsyncPipe, NgClass } from '@angular/common';

class GeocoderService {
    constructor(http, geocoderBaseUrl) {
        this.http = http;
        this.geocoderBaseUrl = geocoderBaseUrl;
        this.geocoderBaseUrl = geocoderBaseUrl;
    }
    suggest$(query, options) {
        let params = {
            q: query,
            fq: '*', // Also get percelen
            start: 0,
        };
        if (options) {
            params = Object.assign(params, options);
        }
        return this.http.get(`${this.geocoderBaseUrl}/suggest?`, { params: params })
            .pipe(map(suggestResultObject => {
            const collations = this.formatCollations(suggestResultObject.spellcheck.collations);
            const places = this.formatPlaces(suggestResultObject);
            return { collations, places };
        }));
    }
    lookup$(id, options) {
        let params = {
            id: id,
            fl: '*'
        };
        if (options) {
            params = Object.assign(params, options);
        }
        return this.http.get(`${this.geocoderBaseUrl}/lookup?`, { params: params }).pipe(map(lookupResponse => this.formatLookupResponse(lookupResponse)));
    }
    free$(searchTerm, options) {
        let params = {
            q: searchTerm,
            fl: '*',
            fq: '*',
            rows: 10,
            start: 0,
        };
        if (options) {
            params = Object.assign(params, options);
        }
        return this.http.get(`${this.geocoderBaseUrl}/free?`, { params: params }).pipe(map(freeResponse => this.formatReverseResponse(freeResponse)));
    }
    reverse$(location, options) {
        let params = {
            fq: '*',
            fl: '*',
            rows: 10,
            distance: 200, // meter,
            lat: location.lat,
            lon: location.lon
        };
        if (options) {
            params = Object.assign(params, options);
        }
        const reverseUrl = `${this.geocoderBaseUrl}/reverse?`;
        return this.http.get(reverseUrl, { params: params }).pipe(map((reverseResponse) => this.formatReverseResponse(reverseResponse)));
    }
    formatCollations(collations) {
        const parsedCollations = [];
        for (let i = 0; i < collations.length; i += 2) {
            const collation = {
                id: i,
                naam: collations[i + 1].misspellingsAndCorrections[1],
                weergavenaam: `${collations[i + 1].hits} resultaten voor <strong> "${collations[i + 1].misspellingsAndCorrections[1]}"</strong>`,
                hits: collations[i + 1].hits,
            };
            parsedCollations.push(collation);
        }
        return parsedCollations;
    }
    formatPlaces(suggestResponse) {
        const places = suggestResponse.response.docs.map((place) => {
            return {
                ...place,
                highlight: suggestResponse.highlighting[place.id].suggest[0]
            };
        });
        return places;
    }
    /**
     * Parse WKT in lookup response.
     */
    formatLookupResponse(lookupResponse) {
        const formatted = lookupResponse.response.docs.map((lookupResult) => {
            const formattedLookupResult = {
                ...lookupResult,
                ...(lookupResult.centroide_ll && { centroide_ll: wktToGeoJSON(lookupResult.centroide_ll) }),
                ...(lookupResult.centroide_rd && { centroide_rd: wktToGeoJSON(lookupResult.centroide_rd) }),
                ...(lookupResult.geometrie_rd && { geometrie_rd: wktToGeoJSON(lookupResult.geometrie_rd) }),
                ...(lookupResult.geometrie_ll && { geometrie_ll: wktToGeoJSON(lookupResult.geometrie_ll) }),
                highlight: lookupResult.weergavenaam,
            };
            return formattedLookupResult;
        });
        return formatted[0] || null;
    }
    formatReverseResponse(lookupResultObject) {
        const formatted = lookupResultObject.response.docs.map((reverseResult) => {
            const formattedLookupResult = {
                ...reverseResult,
                ...(reverseResult.centroide_ll && { centroide_ll: wktToGeoJSON(reverseResult.centroide_ll) }),
                ...(reverseResult.centroide_rd && { centroide_rd: wktToGeoJSON(reverseResult.centroide_rd) }),
                ...(reverseResult.geometrie_rd && { geometrie_rd: wktToGeoJSON(reverseResult.geometrie_rd) }),
                ...(reverseResult.geometrie_ll && { geometrie_ll: wktToGeoJSON(reverseResult.geometrie_ll) }),
                highlight: reverseResult.weergavenaam,
            };
            return formattedLookupResult;
        });
        return formatted;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: GeocoderService, deps: "invalid", target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: GeocoderService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: GeocoderService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: undefined }] });

class GeocoderComponent {
    clickout(event) {
        if (this.geocoderRef.nativeElement.contains(event.target)) {
            this.showSuggestions();
        }
        else {
            this.hideResults();
        }
    }
    constructor(geocoderService, cd) {
        this.geocoderService = geocoderService;
        this.cd = cd;
        this.searchThreshold = 2;
        this.resultCountLimit = 12;
        this.fullscreen = false;
        this.microphone = true;
        this.boxshadow = true;
        this.borderradius = true;
        this.placeFound = new EventEmitter();
        this.clearResults = new EventEmitter();
        this.query = new EventEmitter();
        this.freeSearchResults = new EventEmitter();
        this.blur = new EventEmitter();
        this.hasFocus = false;
        this.formattedPlaceholder = '';
        // Microphone
        this.searchControl = new FormControl(undefined, { validators: [Validators.minLength(this.searchThreshold)] });
        this.microphoneActive$ = new BehaviorSubject(false);
        // Reverse geocoding
        this.userGpsLocation$ = new Subject();
        this.suggest$ = this.searchControl.valueChanges.pipe(filter(searchInput => searchInput.length > this.searchThreshold), debounceTime(200), distinctUntilChanged(), tap((input) => this.query.emit(input)), switchMap(searchInput => this.suggest(searchInput)), shareReplay());
        this.reverseSuggest$ = this.userGpsLocation$.pipe(switchMap((params) => this.reverse(params)), shareReplay());
        this.collationclear$ = new BehaviorSubject([]);
        this.useMyLocationPlace = {
            weergavenaam: 'Gebruik huidige locatie',
            subtitle: 'Zoek met GPS/apparaatlocatie',
            type: 'gps',
            id: 'gps'
        };
        this.tooFewCharacters$ = this.searchControl.valueChanges.pipe(filter(searchInput => searchInput.length <= this.searchThreshold), map(() => [this.useMyLocationPlace]), startWith([this.useMyLocationPlace]));
        this.places$ = merge(this.suggest$.pipe(map((response) => response.places)), this.reverseSuggest$, this.tooFewCharacters$);
        this.collations$ = merge(this.suggest$.pipe(map(response => response.collations)), this.collationclear$);
        this.foundPlace$ = new BehaviorSubject(null);
        this.selectedIndex = -1;
        this.lookupResponseFound = false;
        this.reachedThreshold$ = this.searchControl.valueChanges.pipe(startWith(''), map(val => (val && val.length) > this.searchThreshold));
        this.noPlacesFound$ = this.places$.pipe(map(places => places.length === 0));
        this.noResult$ = this.foundPlace$.pipe(map(place => place === null));
        this.isNoResultsFound$ = combineLatest([this.reachedThreshold$, this.noPlacesFound$, this.noResult$]).pipe(map(([reachedThreshold, noSuggestions, noResult]) => reachedThreshold && noSuggestions && noResult));
    }
    ngOnInit() {
        this.formattedPlaceholder = this.formatPlaceholder(this.placeholder);
    }
    ngOnChanges(changes) {
        if (changes.searchInput) {
            this.searchControl.setValue(changes.searchInput.currentValue);
        }
        if (changes.placeholder) {
            this.formattedPlaceholder = this.formatPlaceholder(changes.placeholder.currentValue);
        }
    }
    suggest(searchTerm) {
        const flArray = ['id', 'score', 'type', 'weergavenaam', 'straatnaam', 'huis_nlt', 'woonplaatsnaam', 'kadastrale_gemeentecode', 'kadastrale_sectie', 'perceelnummer', 'kadastrale_gemeentenaam'];
        const params = {
            fq: '*:*',
            fl: flArray.toString(),
            rows: this.resultCountLimit
        };
        const formattedSearchTerm = this.formatSearchTerm(searchTerm);
        if (this.type) {
            const replace = ',';
            const regex = new RegExp(replace, 'g');
            const query = this.type.replace(regex, ' OR ');
            params.fq = `type:(${query})`;
            if (this.province) {
                params.fq += ` AND provincienaam:(${this.province})`;
            }
        }
        else if (this.province) {
            params.fq = `provincienaam:(${this.province})`;
        }
        return this.geocoderService.suggest$(formattedSearchTerm, params);
    }
    reverse(params) {
        const opts = {
            type: 'adres',
            fq: '*:*',
            rows: this.resultCountLimit
        };
        if (this.type) {
            // Set type to all and use FQ to determine type, so that we can re-use logic
            opts.type = '*';
            const replace = ',';
            const regex = new RegExp(replace, 'g');
            const query = this.type.replace(regex, ' OR ');
            opts.fq = `type:(${query})`;
            if (this.province) {
                opts.fq += ` AND provincienaam:(${this.province})`;
            }
        }
        else if (this.province) {
            opts.fq = `provincienaam:(${this.province})`;
        }
        return this.geocoderService.reverse$(params, opts);
    }
    async lookup(id) {
        const lookupObj = await this.geocoderService.lookup$(id).toPromise();
        this.foundPlace$.next(lookupObj);
        this.fillInput(lookupObj.weergavenaam);
        this.placeFound.emit(lookupObj);
        this.lookupResponseFound = true;
        this.clearPlaces();
        this.hideResults();
    }
    async reverseGeocode() {
        const gpsLocation = await this.getGpsLocation();
        this.userGpsLocation$.next(gpsLocation);
    }
    async free() {
        const params = {
            fq: '*:*',
            rows: this.resultCountLimit
        };
        if (this.type) {
            const replace = ',';
            const regex = new RegExp(replace, 'g');
            const query = this.type.replace(regex, ' OR ');
            params.fq = `type:(${query})`;
            if (this.province) {
                params.fq += ` AND provincienaam:(${this.province})`;
            }
        }
        else if (this.province) {
            params.fq = `provincienaam:(${this.province})`;
        }
        const searchTerm = this.searchControl.value;
        const free = await firstValueFrom(this.geocoderService.free$(searchTerm, params));
        this.freeSearchResults.emit(free);
    }
    clear() {
        this.foundPlace$.next(null);
        this.searchControl.setValue('');
        this.clearPlaces();
        this.lookupResponseFound = false;
        this.hideResults();
        this.clearResults.emit(true);
        this.cd.detectChanges();
    }
    clearPlaces() {
        this.resetIndex();
        this.collationclear$.next([]);
    }
    async handleSuggestClick(id) {
        if (id === 'gps') {
            this.reverseGeocode();
        }
        else {
            this.lookup(id);
        }
    }
    handleEnter(places) {
        if (this.selectedIndex === -1) {
            return;
        }
        const selectedPlace = places[this.selectedIndex];
        this.lookup(selectedPlace.id);
    }
    fillInput(content, emitEvent = false) {
        this.searchControl.setValue(content, {
            emitEvent: emitEvent
        });
    }
    isHighlighted(i) {
        if (i === this.selectedIndex) {
            return true;
        }
    }
    moveUp() {
        if (this.selectedIndex > 0) {
            this.selectedIndex--;
        }
    }
    moveDown(places) {
        if (this.selectedIndex < places.length) {
            this.selectedIndex++;
        }
    }
    resetIndex() {
        this.selectedIndex = -1;
    }
    canQuery() {
        const searchInput = this.searchControl.value;
        return searchInput && searchInput.length > this.searchThreshold;
    }
    canClear() {
        const searchInput = this.searchControl.value;
        return searchInput && searchInput.length > 0;
    }
    formatPlaceholder(placeholder) {
        let placeholderText = 'Zoeken op de kaart...';
        if (placeholder) {
            placeholderText = placeholder;
        }
        return placeholderText;
    }
    onCollationClick(name) {
        this.fillInput(name, true);
    }
    showSuggestions() {
        this.hasFocus = true;
    }
    getSpeechRecognition() {
        if (this.speechRecognizer) {
            return this.speechRecognizer;
        }
        //@ts-ignore
        const SpeechRecognition = window.SpeechRecognition || window.webkitSpeechRecognition;
        const recognition = new SpeechRecognition();
        recognition.interimResults = false; // Set to true if you want interim results
        recognition.lang = 'nl-NL'; // Set the language here
        this.speechRecognizer = recognition;
        return this.speechRecognizer;
    }
    speechToText(event) {
        const recognition = this.getSpeechRecognition();
        if (this.microphoneActive$.getValue() === true) {
            return recognition.stop();
        }
        recognition.onresult = (event) => {
            this.searchControl.setValue(event.results[0][0]?.transcript);
        };
        recognition.onend = (event) => {
            this.microphoneActive$.next(false);
        };
        this.microphoneActive$.next(true);
        recognition.start();
    }
    hideResults() {
        this.hasFocus = false;
    }
    async getGpsLocation() {
        if (!navigator.geolocation) {
            alert('GPS wordt niet ondersteund door uw apparaat');
            return null;
        }
        return new Promise((resolve, reject) => {
            navigator.geolocation.getCurrentPosition((position) => {
                resolve({
                    lat: position.coords.latitude,
                    lon: position.coords.longitude
                });
            }, (error) => {
                const map = {
                    1: 'U heeft ons geen toestemming gegeven om uw locatie op te halen',
                    2: 'Uw locatie is niet beschikbaar',
                    3: 'Het duurt te lang om uw locatie op te halen'
                };
                alert(map[error.code] || 'Het is niet gelukt om uw locatie op te halen');
                reject(error);
            });
        });
    }
    formatSearchTerm(searchTerm) {
        const isKadastraleAanduidingRegex = /[a-zA-Z]{3}[0-9]{2}[a-zA-Z]{1,2}[0-9]{1,5}/;
        if (isKadastraleAanduidingRegex.test(searchTerm) === true) {
            // Use three capturing groups () () () to split the string by.
            const splitAanduidingRegex = /([a-zA-Z]{3}[0-9]{2})([a-zA-Z]{1,2})([0-9]{1,5})/;
            const formattedTerm = searchTerm.split(splitAanduidingRegex).filter(str => str !== '').join(' ');
            return formattedTerm;
        }
        return searchTerm;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: GeocoderComponent, deps: [{ token: GeocoderService }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.0.4", type: GeocoderComponent, selector: "angular-geocoder", inputs: { type: "type", searchInput: "searchInput", placeholder: "placeholder", resultCountLimit: "resultCountLimit", province: "province", fullscreen: "fullscreen", microphone: "microphone", boxshadow: "boxshadow", borderradius: "borderradius" }, outputs: { placeFound: "placeFound", clearResults: "clearResults", query: "query", freeSearchResults: "freeSearchResults", blur: "blur" }, host: { listeners: { "document:click": "clickout($event)" }, properties: { "class.geocoder--selected": "this.hasFocus" }, classAttribute: "geocoder" }, viewQueries: [{ propertyName: "geocoderRef", first: true, predicate: ["geocoder"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "@if (places$ | async; as places) {\r\n<div #geocoder (keydown.ArrowUp)=\"moveUp()\" (keydown.ArrowDown)=\"moveDown(places)\" (keydown.Enter)=\"handleEnter(places)\"\r\n  class=\"geocoder-container\" [class.geocoder-container--fullscreen]=\"hasFocus && fullscreen\"\r\n  [class.boxshadow]=\"boxshadow\" [class.borderradius]=\"borderradius\">\r\n  <!-- Input -->\r\n  <div class=\"geocoder-search\">\r\n    @if (hasFocus === true && fullscreen === true) {\r\n    <button aria-label=\"Terug\" class=\"back\" (click)=\"clear()\">\r\n      <svg viewBox=\"0 0 768 768\" height=\"21\" width=\"21\" fill=\"currentColor\">\r\n        <path\r\n          d=\"M406.624 585.376l-169.376-169.376h370.752c17.664 0 32-14.336 32-32s-14.336-32-32-32h-370.752l169.376-169.376c12.512-12.512 12.512-32.768 0-45.248s-32.768-12.512-45.248 0l-224 224c-3.072 3.072-5.376 6.592-6.944 10.368-1.632 3.904-2.432 8.096-2.432 12.256 0 8.192 3.136 16.384 9.376 22.624l224 224c12.512 12.512 32.768 12.512 45.248 0s12.512-32.768 0-45.248z\">\r\n        </path>\r\n      </svg>\r\n    </button>\r\n    }\r\n\r\n    <input (click)=\"showSuggestions()\"  [formControl]=\"searchControl\" (blur)=\"blur.emit($event)\" class=\"geocoder-search__input\"\r\n      [placeholder]=\"formattedPlaceholder\" type=\"text\" maxlength=\"100\">\r\n\r\n    @if (microphone === true) {\r\n    <button (click)=\"speechToText($event)\" aria-label=\"Zoeken met spraak\" class=\"mic\"\r\n      [class.mic--active]=\"microphoneActive$ |async\">\r\n      <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"17\" height=\"17\" viewBox=\"0 0 24 24\" fill=\"none\"\r\n        stroke=\"currentColor\" stroke-width=\"2\" stroke-linecap=\"round\" stroke-linejoin=\"round\">\r\n        <path d=\"M12 1a3 3 0 0 0-3 3v8a3 3 0 0 0 6 0V4a3 3 0 0 0-3-3z\"></path>\r\n        <path d=\"M19 10v2a7 7 0 0 1-14 0v-2\"></path>\r\n        <line x1=\"12\" y1=\"19\" x2=\"12\" y2=\"23\"></line>\r\n        <line x1=\"8\" y1=\"23\" x2=\"16\" y2=\"23\"></line>\r\n      </svg>\r\n    </button>\r\n    }\r\n\r\n    <button (click)=\"free()\" aria-label=\"Zoeken met tekst\" class=\"search\">\r\n      <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"18\" height=\"18\" viewBox=\"0 0 24 24\" fill=\"none\"\r\n        stroke=\"currentColor\" stroke-width=\"2\" stroke-linecap=\"round\" stroke-linejoin=\"round\">\r\n        <circle cx=\"11\" cy=\"11\" r=\"8\"></circle>\r\n        <line x1=\"21\" y1=\"21\" x2=\"16.65\" y2=\"16.65\"></line>\r\n      </svg>\r\n    </button>\r\n    @if (lookupResponseFound === true) {\r\n    <button aria-label=\"Sluiten\" class=\"close\" width=\"15\" height=\"15\" (click)=\"clear()\">\r\n      <svg viewBox=\"0 0 384 512\">\r\n        <path fill=\"currentColor\"\r\n          d=\"M217.5 256l137.2-137.2c4.7-4.7 4.7-12.3 0-17l-8.5-8.5c-4.7-4.7-12.3-4.7-17 0L192 230.5 54.8 93.4c-4.7-4.7-12.3-4.7-17 0l-8.5 8.5c-4.7 4.7-4.7 12.3 0 17L166.5 256 29.4 393.2c-4.7 4.7-4.7 12.3 0 17l8.5 8.5c4.7 4.7 12.3 4.7 17 0L192 281.5l137.2 137.2c4.7 4.7 12.3 4.7 17 0l8.5-8.5c4.7-4.7 4.7-12.3 0-17L217.5 256z\"\r\n          class=\"\"></path>\r\n      </svg>\r\n    </button>\r\n    }\r\n\r\n\r\n  </div>\r\n\r\n\r\n  <!-- Search results-->\r\n  @if (hasFocus === true) {\r\n  @if (places.length > 0) {\r\n  <div class=\"geocoder-suggestions\">\r\n    <ul class=\"geocoder-suggestions__list\">\r\n      @for (place of places; track place.id; let i = $index) {\r\n      <li class=\"geocoder-suggestion\" tabindex={{i}} (click)=\"handleSuggestClick(place.id)\"\r\n        [ngClass]=\"{'geocoder-suggestion--focus': isHighlighted(i)}\">\r\n\r\n        @switch (place.type) {\r\n        @case ('gps') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            {{ place.weergavenaam }}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.subtitle}}</div>\r\n        </div>\r\n        }\r\n\r\n        @case ('adres') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            {{place.straatnaam }} {{place.huis_nlt}}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.woonplaatsnaam}}</div>\r\n        </div>\r\n        }\r\n\r\n        @case ('perceel') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            Perceel {{place.kadastrale_gemeentecode }} {{place.kadastrale_sectie}} {{place.perceelnummer}}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.kadastrale_gemeentenaam}}</div>\r\n        </div>\r\n        }\r\n\r\n        @case ('weg') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            {{place.straatnaam }}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.woonplaatsnaam}}</div>\r\n        </div>\r\n        }\r\n\r\n        @default {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\" [innerHTML]=\"place.highlight\">\r\n          </div>\r\n        </div>\r\n        }\r\n\r\n        }\r\n        <div class=\"geocoder-suggestion__type\"> {{place.type}} </div>\r\n\r\n      </li>\r\n      }\r\n\r\n    </ul>\r\n  </div>\r\n  }\r\n\r\n  @if ((isNoResultsFound$ | async) === true) {\r\n  <div class=\"geocoder-noresults\">\r\n    Geen resultaten voor <strong>\"{{searchControl.value}}\"</strong>\r\n  </div>\r\n  }\r\n\r\n  @if (collations$ | async; as collations) {\r\n  @if(noResult$ | async; as noResult) {\r\n\r\n  @if (collations.length > 0 && places.length === 0 && noResult) {\r\n  <div class=\"geocoder-suggestions geocoder-suggestions--collations\">\r\n    <ul class=\"geocoder-suggestions__list\">\r\n      @for(collation of collations; track collation.naam; let i = $index) {\r\n      <li class=\"geocoder-suggestion\" tabindex={{i}} (click)=\"onCollationClick(collation.naam)\"\r\n        [innerHTML]=\"collation.weergavenaam\">\r\n      </li>\r\n      }\r\n    </ul>\r\n  </div>\r\n  }\r\n  }\r\n  }\r\n\r\n  <!-- Backdrop-->\r\n  @if (fullscreen === true) {\r\n  <div class=\"geocoder-backdrop\"></div>\r\n  }\r\n  }\r\n\r\n</div>\r\n}", styles: ["*:focus{outline:0}::placeholder{color:#797979}.geocoder-container{position:relative;width:100%;height:100%;max-width:100%;overscroll-behavior-y:none;line-height:19px;font-size:13px;color:#444}.geocoder-container--fullscreen{position:fixed;top:0;right:0;left:0;height:100vh;height:100dvh}.geocoder-search{position:relative;display:flex;align-items:center;width:100%;z-index:1;background:#fff;box-sizing:border-box;border:1px solid #eee}.geocoder-search__input{flex:1 1 auto;margin:0;padding:14px 15px;max-width:calc(100% - 70px);overflow:hidden;text-overflow:ellipsis;border-radius:15px;border:none}button{display:flex;align-items:center;padding:0 15px;cursor:pointer;background:#fff;border:none}button.close{position:absolute;right:0}button.mic{padding:0 8px 0 0}button.back{padding-right:0}svg{width:18px;height:auto;color:#797979}button.back svg{width:21px}button.mic svg{width:17px}button.close svg{width:15px}button:hover svg{color:#008cba}button.mic--active svg{animation:pulse 1s infinite}@keyframes pulse{0%{color:#797979}50%{color:#3498db}to{color:#797979}}.geocoder-suggestions{position:relative;width:100%;z-index:2;max-height:calc(100% - 49px);overflow-y:auto;overscroll-behavior-y:none;border:1px solid #eee;border-width:0 1px 1px;background:#fff}.geocoder-suggestions__list{margin:0;padding:0;list-style-type:none}.geocoder-suggestion{display:flex;gap:5px;align-items:center;margin:0;padding:12px 15px;border-bottom:1px solid #eee;cursor:pointer}.geocoder-suggestion:last-of-type{border-bottom:none}.geocoder-suggestion:hover,.geocoder-suggestion--focus{background-color:#f7f7f7}.geocoder-suggestion__content{margin-right:10px}.geocoder-suggestion__content__subtitle{color:#838383}.geocoder-suggestion__type{margin:0 0 0 auto;font-size:11px;font-weight:700;text-transform:uppercase;color:#bfbfbf}.geocoder-noresults{position:relative;width:100%;padding:18px 15px;z-index:1;background:#fff;border:1px solid #eee;border-width:0 1px 1px;box-sizing:border-box}.geocoder-backdrop{position:fixed;inset:0;height:100%;width:100%;z-index:0;background:#f5f5f5}.borderradius .geocoder-search,.borderradius .geocoder-search__input{border-radius:0 0 15px 15px}@media (min-width: 787px){.borderradius .geocoder-search,.borderradius .geocoder-search__input{border-radius:15px}}.borderradius button,.borderradius .geocoder-suggestions,.borderradius .geocoder-noresults{border-radius:15px}.boxshadow .geocoder-search,.boxshadow .geocoder-suggestions,.boxshadow .geocoder-noresults{box-shadow:0 2px 4px #0003,0 -1px #00000005;border:none}\n"], dependencies: [{ kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i3.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i3.MaxLengthValidator, selector: "[maxlength][formControlName],[maxlength][formControl],[maxlength][ngModel]", inputs: ["maxlength"] }, { kind: "directive", type: i3.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "pipe", type: i2.AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: GeocoderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'angular-geocoder', host: { 'class': 'geocoder' }, changeDetection: ChangeDetectionStrategy.OnPush, template: "@if (places$ | async; as places) {\r\n<div #geocoder (keydown.ArrowUp)=\"moveUp()\" (keydown.ArrowDown)=\"moveDown(places)\" (keydown.Enter)=\"handleEnter(places)\"\r\n  class=\"geocoder-container\" [class.geocoder-container--fullscreen]=\"hasFocus && fullscreen\"\r\n  [class.boxshadow]=\"boxshadow\" [class.borderradius]=\"borderradius\">\r\n  <!-- Input -->\r\n  <div class=\"geocoder-search\">\r\n    @if (hasFocus === true && fullscreen === true) {\r\n    <button aria-label=\"Terug\" class=\"back\" (click)=\"clear()\">\r\n      <svg viewBox=\"0 0 768 768\" height=\"21\" width=\"21\" fill=\"currentColor\">\r\n        <path\r\n          d=\"M406.624 585.376l-169.376-169.376h370.752c17.664 0 32-14.336 32-32s-14.336-32-32-32h-370.752l169.376-169.376c12.512-12.512 12.512-32.768 0-45.248s-32.768-12.512-45.248 0l-224 224c-3.072 3.072-5.376 6.592-6.944 10.368-1.632 3.904-2.432 8.096-2.432 12.256 0 8.192 3.136 16.384 9.376 22.624l224 224c12.512 12.512 32.768 12.512 45.248 0s12.512-32.768 0-45.248z\">\r\n        </path>\r\n      </svg>\r\n    </button>\r\n    }\r\n\r\n    <input (click)=\"showSuggestions()\"  [formControl]=\"searchControl\" (blur)=\"blur.emit($event)\" class=\"geocoder-search__input\"\r\n      [placeholder]=\"formattedPlaceholder\" type=\"text\" maxlength=\"100\">\r\n\r\n    @if (microphone === true) {\r\n    <button (click)=\"speechToText($event)\" aria-label=\"Zoeken met spraak\" class=\"mic\"\r\n      [class.mic--active]=\"microphoneActive$ |async\">\r\n      <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"17\" height=\"17\" viewBox=\"0 0 24 24\" fill=\"none\"\r\n        stroke=\"currentColor\" stroke-width=\"2\" stroke-linecap=\"round\" stroke-linejoin=\"round\">\r\n        <path d=\"M12 1a3 3 0 0 0-3 3v8a3 3 0 0 0 6 0V4a3 3 0 0 0-3-3z\"></path>\r\n        <path d=\"M19 10v2a7 7 0 0 1-14 0v-2\"></path>\r\n        <line x1=\"12\" y1=\"19\" x2=\"12\" y2=\"23\"></line>\r\n        <line x1=\"8\" y1=\"23\" x2=\"16\" y2=\"23\"></line>\r\n      </svg>\r\n    </button>\r\n    }\r\n\r\n    <button (click)=\"free()\" aria-label=\"Zoeken met tekst\" class=\"search\">\r\n      <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"18\" height=\"18\" viewBox=\"0 0 24 24\" fill=\"none\"\r\n        stroke=\"currentColor\" stroke-width=\"2\" stroke-linecap=\"round\" stroke-linejoin=\"round\">\r\n        <circle cx=\"11\" cy=\"11\" r=\"8\"></circle>\r\n        <line x1=\"21\" y1=\"21\" x2=\"16.65\" y2=\"16.65\"></line>\r\n      </svg>\r\n    </button>\r\n    @if (lookupResponseFound === true) {\r\n    <button aria-label=\"Sluiten\" class=\"close\" width=\"15\" height=\"15\" (click)=\"clear()\">\r\n      <svg viewBox=\"0 0 384 512\">\r\n        <path fill=\"currentColor\"\r\n          d=\"M217.5 256l137.2-137.2c4.7-4.7 4.7-12.3 0-17l-8.5-8.5c-4.7-4.7-12.3-4.7-17 0L192 230.5 54.8 93.4c-4.7-4.7-12.3-4.7-17 0l-8.5 8.5c-4.7 4.7-4.7 12.3 0 17L166.5 256 29.4 393.2c-4.7 4.7-4.7 12.3 0 17l8.5 8.5c4.7 4.7 12.3 4.7 17 0L192 281.5l137.2 137.2c4.7 4.7 12.3 4.7 17 0l8.5-8.5c4.7-4.7 4.7-12.3 0-17L217.5 256z\"\r\n          class=\"\"></path>\r\n      </svg>\r\n    </button>\r\n    }\r\n\r\n\r\n  </div>\r\n\r\n\r\n  <!-- Search results-->\r\n  @if (hasFocus === true) {\r\n  @if (places.length > 0) {\r\n  <div class=\"geocoder-suggestions\">\r\n    <ul class=\"geocoder-suggestions__list\">\r\n      @for (place of places; track place.id; let i = $index) {\r\n      <li class=\"geocoder-suggestion\" tabindex={{i}} (click)=\"handleSuggestClick(place.id)\"\r\n        [ngClass]=\"{'geocoder-suggestion--focus': isHighlighted(i)}\">\r\n\r\n        @switch (place.type) {\r\n        @case ('gps') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            {{ place.weergavenaam }}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.subtitle}}</div>\r\n        </div>\r\n        }\r\n\r\n        @case ('adres') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            {{place.straatnaam }} {{place.huis_nlt}}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.woonplaatsnaam}}</div>\r\n        </div>\r\n        }\r\n\r\n        @case ('perceel') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            Perceel {{place.kadastrale_gemeentecode }} {{place.kadastrale_sectie}} {{place.perceelnummer}}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.kadastrale_gemeentenaam}}</div>\r\n        </div>\r\n        }\r\n\r\n        @case ('weg') {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\">\r\n            {{place.straatnaam }}\r\n          </div>\r\n          <div class=\"geocoder-suggestion__content__subtitle\"> {{place.woonplaatsnaam}}</div>\r\n        </div>\r\n        }\r\n\r\n        @default {\r\n        <div class=\"geocoder-suggestion__content\">\r\n          <div class=\"geocoder-suggestion__content__title\" [innerHTML]=\"place.highlight\">\r\n          </div>\r\n        </div>\r\n        }\r\n\r\n        }\r\n        <div class=\"geocoder-suggestion__type\"> {{place.type}} </div>\r\n\r\n      </li>\r\n      }\r\n\r\n    </ul>\r\n  </div>\r\n  }\r\n\r\n  @if ((isNoResultsFound$ | async) === true) {\r\n  <div class=\"geocoder-noresults\">\r\n    Geen resultaten voor <strong>\"{{searchControl.value}}\"</strong>\r\n  </div>\r\n  }\r\n\r\n  @if (collations$ | async; as collations) {\r\n  @if(noResult$ | async; as noResult) {\r\n\r\n  @if (collations.length > 0 && places.length === 0 && noResult) {\r\n  <div class=\"geocoder-suggestions geocoder-suggestions--collations\">\r\n    <ul class=\"geocoder-suggestions__list\">\r\n      @for(collation of collations; track collation.naam; let i = $index) {\r\n      <li class=\"geocoder-suggestion\" tabindex={{i}} (click)=\"onCollationClick(collation.naam)\"\r\n        [innerHTML]=\"collation.weergavenaam\">\r\n      </li>\r\n      }\r\n    </ul>\r\n  </div>\r\n  }\r\n  }\r\n  }\r\n\r\n  <!-- Backdrop-->\r\n  @if (fullscreen === true) {\r\n  <div class=\"geocoder-backdrop\"></div>\r\n  }\r\n  }\r\n\r\n</div>\r\n}", styles: ["*:focus{outline:0}::placeholder{color:#797979}.geocoder-container{position:relative;width:100%;height:100%;max-width:100%;overscroll-behavior-y:none;line-height:19px;font-size:13px;color:#444}.geocoder-container--fullscreen{position:fixed;top:0;right:0;left:0;height:100vh;height:100dvh}.geocoder-search{position:relative;display:flex;align-items:center;width:100%;z-index:1;background:#fff;box-sizing:border-box;border:1px solid #eee}.geocoder-search__input{flex:1 1 auto;margin:0;padding:14px 15px;max-width:calc(100% - 70px);overflow:hidden;text-overflow:ellipsis;border-radius:15px;border:none}button{display:flex;align-items:center;padding:0 15px;cursor:pointer;background:#fff;border:none}button.close{position:absolute;right:0}button.mic{padding:0 8px 0 0}button.back{padding-right:0}svg{width:18px;height:auto;color:#797979}button.back svg{width:21px}button.mic svg{width:17px}button.close svg{width:15px}button:hover svg{color:#008cba}button.mic--active svg{animation:pulse 1s infinite}@keyframes pulse{0%{color:#797979}50%{color:#3498db}to{color:#797979}}.geocoder-suggestions{position:relative;width:100%;z-index:2;max-height:calc(100% - 49px);overflow-y:auto;overscroll-behavior-y:none;border:1px solid #eee;border-width:0 1px 1px;background:#fff}.geocoder-suggestions__list{margin:0;padding:0;list-style-type:none}.geocoder-suggestion{display:flex;gap:5px;align-items:center;margin:0;padding:12px 15px;border-bottom:1px solid #eee;cursor:pointer}.geocoder-suggestion:last-of-type{border-bottom:none}.geocoder-suggestion:hover,.geocoder-suggestion--focus{background-color:#f7f7f7}.geocoder-suggestion__content{margin-right:10px}.geocoder-suggestion__content__subtitle{color:#838383}.geocoder-suggestion__type{margin:0 0 0 auto;font-size:11px;font-weight:700;text-transform:uppercase;color:#bfbfbf}.geocoder-noresults{position:relative;width:100%;padding:18px 15px;z-index:1;background:#fff;border:1px solid #eee;border-width:0 1px 1px;box-sizing:border-box}.geocoder-backdrop{position:fixed;inset:0;height:100%;width:100%;z-index:0;background:#f5f5f5}.borderradius .geocoder-search,.borderradius .geocoder-search__input{border-radius:0 0 15px 15px}@media (min-width: 787px){.borderradius .geocoder-search,.borderradius .geocoder-search__input{border-radius:15px}}.borderradius button,.borderradius .geocoder-suggestions,.borderradius .geocoder-noresults{border-radius:15px}.boxshadow .geocoder-search,.boxshadow .geocoder-suggestions,.boxshadow .geocoder-noresults{box-shadow:0 2px 4px #0003,0 -1px #00000005;border:none}\n"] }]
        }], ctorParameters: () => [{ type: GeocoderService }, { type: i0.ChangeDetectorRef }], propDecorators: { geocoderRef: [{
                type: ViewChild,
                args: ['geocoder', { static: false }]
            }], type: [{
                type: Input
            }], searchInput: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], resultCountLimit: [{
                type: Input
            }], province: [{
                type: Input
            }], fullscreen: [{
                type: Input
            }], microphone: [{
                type: Input
            }], boxshadow: [{
                type: Input
            }], borderradius: [{
                type: Input
            }], placeFound: [{
                type: Output
            }], clearResults: [{
                type: Output
            }], query: [{
                type: Output
            }], freeSearchResults: [{
                type: Output
            }], blur: [{
                type: Output
            }], hasFocus: [{
                type: HostBinding,
                args: ['class.geocoder--selected']
            }], clickout: [{
                type: HostListener,
                args: ['document:click', ['$event']]
            }] } });

class GeocoderModule {
    // I setup the module providers for the root application.
    static forRoot(options) {
        return ({
            ngModule: GeocoderModule,
            providers: [
                // In order to translate the raw, optional OPTIONS argument into an
                // instance of the GeocoderServiceOptions TYPE, we have to first provide it as
                // an injectable so that we can inject it into our FACTORY FUNCTION.
                {
                    provide: FOR_ROOT_OPTIONS_TOKEN,
                    useValue: options
                },
                // Once we've provided the OPTIONS as an injectable, we can use a FACTORY
                // FUNCTION to then take that raw configuration object and use it to
                // configure an instance of the GeocoderServiceOptions TYPE (which will be
                // implicitly consumed by the  GeocoderService constructor).
                {
                    provide: GeocoderService,
                    useFactory: provideGeocoderServiceOptions,
                    deps: [HttpClient, FOR_ROOT_OPTIONS_TOKEN]
                },
            ]
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: GeocoderModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.0.4", ngImport: i0, type: GeocoderModule, declarations: [GeocoderComponent], imports: [AsyncPipe,
            NgClass,
            ReactiveFormsModule], exports: [GeocoderComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: GeocoderModule, providers: [
            provideHttpClient()
        ], imports: [ReactiveFormsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.4", ngImport: i0, type: GeocoderModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [GeocoderComponent],
                    exports: [GeocoderComponent],
                    imports: [
                        AsyncPipe,
                        NgClass,
                        ReactiveFormsModule
                    ],
                    providers: [
                        provideHttpClient()
                    ]
                }]
        }] });
var FOR_ROOT_OPTIONS_TOKEN = new InjectionToken("forRoot() GeocoderService configuration.");
// NOTE: This value has to be exported otherwise the AoT compiler won't see it.
function provideGeocoderServiceOptions(http, options) {
    const baseUrl = options?.geocoderBaseUrl || 'https://api.pdok.nl/bzk/locatieserver/search/v3_1';
    return new GeocoderService(http, baseUrl);
}

/*
 * Public API Surface of angular-geocoder
 */

/**
 * Generated bundle index. Do not edit.
 */

export { FOR_ROOT_OPTIONS_TOKEN, GeocoderComponent, GeocoderModule, GeocoderService, provideGeocoderServiceOptions };
//# sourceMappingURL=angular-geocoder.mjs.map
