import { HttpClient } from '@angular/common/http';
import { ReverseOptions, ReverseGeometry, SuggestOptions, LookupOptions, SuggestObjectWithHighlight, ParsedPlaceObject } from './locatieserver.model';
import * as GeoJSON from 'geojson';
import * as i0 from "@angular/core";
export declare class GeocoderService {
    private http;
    private geocoderBaseUrl;
    constructor(http: HttpClient, geocoderBaseUrl: string);
    suggest$(query: string, options?: SuggestOptions): import("rxjs").Observable<{
        collations: any[];
        places: SuggestObjectWithHighlight[];
    }>;
    lookup$(id: string, options?: LookupOptions): import("rxjs").Observable<ParsedPlaceObject>;
    free$(searchTerm: string, options?: SuggestOptions): import("rxjs").Observable<({
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "NWB";
        identificatie: string;
        hectometerletter: string;
        type: "hectometerpaal";
        wegnummer: string;
        hectometernummer: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        volgnummer: number;
        type: "appartementsrecht";
        perceelnummer: number;
        weergavenaam: string;
        suggest: string[];
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "HWH";
        identificatie: string;
        waterschapsnaam: string;
        type: "waterschap";
        waterschapscode: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "buurt";
        provincienaam: string;
        wijkcode: string;
        buurtnaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        buurtcode: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "wijk";
        provincienaam: string;
        wijkcode: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        kadastrale_grootte: number;
        suggest: string[];
        type: "perceel";
        perceelnummer: number;
        weergavenaam: string;
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "BAG";
        woonplaatscode: string;
        type: "adres";
        woonplaatsnaam: string;
        wijkcode: string;
        huis_nlt: string;
        openbareruimtetype: string;
        buurtnaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        adrestype: string;
        straatnaam_verkort: string;
        id: string;
        gekoppeld_perceel: string[];
        gemeentenaam: string;
        buurtcode: string;
        wijknaam: string;
        identificatie: string;
        openbareruimte_id: string;
        waterschapsnaam: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        nummeraanduiding_id: string;
        waterschapscode: string;
        adresseerbaarobject_id: string;
        huisnummer: number;
        huisletter?: string;
        huisnummertoevoeging?: string;
        provincieafkorting: string;
        straatnaam: string;
        gekoppeld_appartement: string[];
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "BAG";
        suggest: string[];
        woonplaatscode: string;
        type: "postcode";
        woonplaatsnaam: string;
        openbareruimtetype: string;
        gemeentecode: string;
        weergavenaam: string;
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "BAG/NWB";
        woonplaatscode: string;
        type: "weg";
        woonplaatsnaam: string;
        nwb_id: string;
        openbareruimtetype: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "BAG";
        identificatie: string;
        provinciecode: string;
        woonplaatscode: string;
        type: "woonplaats";
        woonplaatsnaam: string;
        provincienaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "gemeente";
        provincienaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "provincie";
        provincienaam: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    })[]>;
    reverse$(location: ReverseGeometry, options?: ReverseOptions): import("rxjs").Observable<({
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "NWB";
        identificatie: string;
        hectometerletter: string;
        type: "hectometerpaal";
        wegnummer: string;
        hectometernummer: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        volgnummer: number;
        type: "appartementsrecht";
        perceelnummer: number;
        weergavenaam: string;
        suggest: string[];
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "HWH";
        identificatie: string;
        waterschapsnaam: string;
        type: "waterschap";
        waterschapscode: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "buurt";
        provincienaam: string;
        wijkcode: string;
        buurtnaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        buurtcode: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "wijk";
        provincienaam: string;
        wijkcode: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        kadastrale_grootte: number;
        suggest: string[];
        type: "perceel";
        perceelnummer: number;
        weergavenaam: string;
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "BAG";
        woonplaatscode: string;
        type: "adres";
        woonplaatsnaam: string;
        wijkcode: string;
        huis_nlt: string;
        openbareruimtetype: string;
        buurtnaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        adrestype: string;
        straatnaam_verkort: string;
        id: string;
        gekoppeld_perceel: string[];
        gemeentenaam: string;
        buurtcode: string;
        wijknaam: string;
        identificatie: string;
        openbareruimte_id: string;
        waterschapsnaam: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        nummeraanduiding_id: string;
        waterschapscode: string;
        adresseerbaarobject_id: string;
        huisnummer: number;
        huisletter?: string;
        huisnummertoevoeging?: string;
        provincieafkorting: string;
        straatnaam: string;
        gekoppeld_appartement: string[];
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "BAG";
        suggest: string[];
        woonplaatscode: string;
        type: "postcode";
        woonplaatsnaam: string;
        openbareruimtetype: string;
        gemeentecode: string;
        weergavenaam: string;
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "BAG/NWB";
        woonplaatscode: string;
        type: "weg";
        woonplaatsnaam: string;
        nwb_id: string;
        openbareruimtetype: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "BAG";
        identificatie: string;
        provinciecode: string;
        woonplaatscode: string;
        type: "woonplaats";
        woonplaatsnaam: string;
        provincienaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "gemeente";
        provincienaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: GeoJSON.GeoJSON;
        geometrie_rd: GeoJSON.GeoJSON;
        centroide_rd: GeoJSON.GeoJSON;
        centroide_ll: GeoJSON.GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "provincie";
        provincienaam: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    })[]>;
    private formatCollations;
    private formatPlaces;
    /**
     * Parse WKT in lookup response.
     */
    private formatLookupResponse;
    private formatReverseResponse;
    static ɵfac: i0.ɵɵFactoryDeclaration<GeocoderService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<GeocoderService>;
}
